@@ -4,9 +4,7 @@ use 5.008003;
 use warnings;
 use strict;
 
-our $VERSION = '0.901';
-$VERSION =~ s/_//sm;
-
+our $VERSION = '0.993';
 
 # Documentation module only.
 
@@ -17,7 +15,7 @@ __END__
 
 =begin readme text
 
-Dist::Zilla::BeLike::CSJEWELL version 0.901
+Dist::Zilla::BeLike::CSJEWELL version 0.993
 
 =end readme
 
@@ -37,20 +35,20 @@ This document describes Dist::Zilla::BeLike::CSJEWELL version 0.901.
 
 To install this module, run the following commands:
 
-	perl Makefile.PL
-	make
-	make test
-	make install
+    perl Makefile.PL
+    make
+    make test
+    make install
 
 This method of installation will require a current version of Module::Build 
 if it is not already installed.
     
 Alternatively, to install with Module::Build, you can use the following commands:
 
-	perl Build.PL
-	./Build
-	./Build test
-	./Build install
+    perl Build.PL
+    ./Build
+    ./Build test
+    ./Build install
 
 =end readme
 
@@ -58,11 +56,11 @@ Alternatively, to install with Module::Build, you can use the following commands
 
 =head1 SYNOPSIS
 
-	# After 'dzil setup'
-	dzil configure_CSJEWELL
-	
-	# To create a module
-	dzil new -P CSJEWELL Your::Module
+    # After 'dzil setup'
+    dzil configure_CSJEWELL
+    
+    # To create a module
+    dzil new -P CSJEWELL Your::Module
 
 =head1 DESCRIPTION
 
@@ -78,7 +76,7 @@ The configuration questions are asked for in the C<dzil configure_CSJEWELL> comm
 =head1 DEPENDENCIES
 
 This module depends on L<Dist::Zilla|Dist::Zilla> version 4.102221 or greater,
-L<Dist::Zilla::Plugin::Mercurial|Dist::Zilla::Plugin::Mercurial>, 
+L<Dist::Zilla::Plugin::Git|Dist::Zilla::Plugin::Git>, 
 L<Dist::Zilla::Plugin::Twitter|Dist::Zilla::Plugin::Twitter>, ...
 
 =for readme stop
@@ -89,9 +87,6 @@ None reported.
 
 =head1 BUGS AND LIMITATIONS
 
-This module does not know how to automatically handle any Mercurial servers 
-other than bitbucket.org, or any other VCS or DVCS server at the moment.
-
 No bugs have been reported.
 
 Bugs should be reported via: 
@@ -109,7 +104,7 @@ Curtis Jewell <CSJewell@cpan.org>
 
 =head1 LICENSE AND COPYRIGHT
 
-Copyright (c) 2010, Curtis Jewell C<< CSJewell@cpan.org >>.
+Copyright (c) 2010, 2014, 2021 Curtis Jewell C<< CSJewell@cpan.org >>.
 
 This module is free software; you can redistribute it and/or
 modify it under the same terms as Perl itself, either version
